@@ -28,14 +28,19 @@
 
 import urllib
 import pickle
+import time
+import sys
+from httplib import HTTPSConnection
+import jwt
 
-from Requester import Requester
+from Requester import Requester, json
 import AuthenticatedUser
 import NamedUser
 import Organization
 import Gist
 import github.PaginatedList
 import Repository
+import Installation
 import Legacy
 import github.GithubObject
 import HookDescription
@@ -43,7 +48,11 @@ import GitignoreTemplate
 import Status
 import StatusMessage
 import RateLimit
+import InstallationAuthorization
+import GithubException
+import Invitation
 
+atLeastPython3 = sys.hexversion >= 0x03000000
 
 DEFAULT_BASE_URL = "https://api.github.com"
 DEFAULT_TIMEOUT = 10
@@ -590,3 +599,99 @@ class Github(object):
             cnx="status"
         )
         return [StatusMessage.StatusMessage(self.__requester, headers, attributes, completed=True) for attributes in data]
+
+    def get_installation(self, id):
+        """
+
+        :param id:
+        :return:
+        """
+        return Installation.Installation(self.__requester, headers={}, attributes={"id": id}, completed=True)
+
+
+class GithubIntegration(object):
+    """
+    Main class to obtain tokens for a GitHub integration.
+    """
+
+    def __init__(self, integration_id, private_key):
+        """
+        :param integration_id: int
+        :param private_key: string
+        """
+        self.integration_id = integration_id
+        self.private_key = private_key
+
+    def create_jwt(self):
+        """
+        Creates a signed JWT, valid for 60 seconds.
+        :return:
+        """
+        now = int(time.time())
+        payload = {
+            "iat": now,
+            "exp": now + 60,
+            "iss": self.integration_id
+        }
+        encrypted = jwt.encode(
+            payload,
+            key=self.private_key,
+            algorithm="RS256"
+        )
+
+        if atLeastPython3:
+            encrypted = encrypted.decode('utf-8')
+
+        return encrypted
+
+    def get_access_token(self, installation_id, user_id=None):
+        """
+        Get an access token for the given installation id.
+        POSTs https://api.github.com/installations/<installation_id>/access_tokens
+        :param user_id: int
+        :param installation_id: int
+        :return: :class:`github.InstallationAuthorization.InstallationAuthorization`
+        """
+        body = None
+        if user_id:
+            body = json.dumps({"user_id": user_id})
+        conn = HTTPSConnection("api.github.com")
+        conn.request(
+            method="POST",
+            url="/installations/{}/access_tokens".format(installation_id),
+            headers={
+                "Authorization": "Bearer {}".format(self.create_jwt()),
+                "Accept": "application/vnd.github.machine-man-preview+json",
+                "User-Agent": "PyGithub/Python"
+            },
+            body=body
+        )
+        response = conn.getresponse()
+        response_text = response.read()
+
+        if atLeastPython3:
+            response_text = response_text.decode('utf-8')
+
+        conn.close()
+        if response.status == 201:
+            data = json.loads(response_text)
+            return InstallationAuthorization.InstallationAuthorization(
+                requester=None,  # not required, this is a NonCompletableGithubObject
+                headers={},  # not required, this is a NonCompletableGithubObject
+                attributes=data,
+                completed=True
+            )
+        elif response.status == 403:
+            raise GithubException.BadCredentialsException(
+                status=response.status,
+                data=response_text
+            )
+        elif response.status == 404:
+            raise GithubException.UnknownObjectException(
+                status=response.status,
+                data=response_text
+            )
+        raise GithubException.GithubException(
+            status=response.status,
+            data=response_text
+        )
