@@ -24,7 +24,7 @@
 #                                                                              #
 # ##############################################################################
 
-import Framework
+from . import Framework
 
 import github
 import datetime
@@ -65,6 +65,9 @@ class AuthenticatedUser(Framework.TestCase):
         self.assertEqual(self.user.type, "User")
         self.assertEqual(self.user.url, "https://api.github.com/users/jacquev6")
 
+        # test __repr__() based on this attributes
+        self.assertEqual(self.user.__repr__(), 'AuthenticatedUser(login="jacquev6")')
+
     def testEditWithoutArguments(self):
         self.user.edit()
 
@@ -126,15 +129,16 @@ class AuthenticatedUser(Framework.TestCase):
         self.assertListKeyEqual(self.user.get_authorizations(), lambda a: a.id, [372294])
 
     def testCreateRepository(self):
-        repo = self.user.create_repo("TestPyGithub")
+        repo = self.user.create_repo(name="TestPyGithub")
         self.assertEqual(repo.url, "https://api.github.com/repos/jacquev6/TestPyGithub")
 
     def testCreateRepositoryWithAllArguments(self):
-        repo = self.user.create_repo("TestPyGithub", "Repo created by PyGithub", "http://foobar.com", private=False, has_issues=False, has_wiki=False, has_downloads=False)
+        repo = self.user.create_repo(name="TestPyGithub", description="Repo created by PyGithub", homepage="http://foobar.com",
+                                     private=False, has_issues=False, has_wiki=False, has_downloads=False)
         self.assertEqual(repo.url, "https://api.github.com/repos/jacquev6/TestPyGithub")
 
     def testCreateRepositoryWithAutoInit(self):
-        repo = self.user.create_repo("TestPyGithub", auto_init=True, gitignore_template="Python")
+        repo = self.user.create_repo(name="TestPyGithub", auto_init=True, gitignore_template="Python")
         self.assertEqual(repo.url, "https://api.github.com/repos/jacquev6/TestPyGithub")
 
     def testCreateAuthorizationWithoutArguments(self):
@@ -153,13 +157,13 @@ class AuthenticatedUser(Framework.TestCase):
     def testCreateGist(self):
         gist = self.user.create_gist(True, {"foobar.txt": github.InputFileContent("File created by PyGithub")}, "Gist created by PyGithub")
         self.assertEqual(gist.description, "Gist created by PyGithub")
-        self.assertEqual(gist.files.keys(), ["foobar.txt"])
+        self.assertEqual(list(gist.files.keys()), ["foobar.txt"])
         self.assertEqual(gist.files["foobar.txt"].content, "File created by PyGithub")
 
     def testCreateGistWithoutDescription(self):
         gist = self.user.create_gist(True, {"foobar.txt": github.InputFileContent("File created by PyGithub")})
         self.assertEqual(gist.description, None)
-        self.assertEqual(gist.files.keys(), ["foobar.txt"])
+        self.assertEqual(list(gist.files.keys()), ["foobar.txt"])
         self.assertEqual(gist.files["foobar.txt"].content, "File created by PyGithub")
 
     def testCreateKey(self):
@@ -231,3 +235,6 @@ class AuthenticatedUser(Framework.TestCase):
 
     def testGetTeams(self):
         self.assertListKeyEqual(self.user.get_teams(), lambda t: t.name, ["Owners", "Honoraries", "Honoraries", "Honoraries", "Honoraries", "Honoraries", "Honoraries", "Honoraries", "Honoraries", "Honoraries"])
+
+    def testAcceptInvitation(self):
+        self.assertEqual(self.user.accept_invitation(4294886), None)
